const base64Pattern = /^(?:[A-Za-z0-9+/]{4})*?(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$/;
/**
 * Decodes a value from base64.
 * @public
 * @param value - The value to decode from base64.
 * @returns The decoded value.
 */
export const decodeFromBase64 = (base64Value) => {
    if (base64Pattern.test(base64Value)) {
        const decodedString = atob(base64Value);
        const buffer = new Uint8Array(decodedString.length);
        [...decodedString].forEach((_, i) => {
            buffer[i] = decodedString.charCodeAt(i);
        });
        return buffer.buffer;
    }
    return base64Value;
};
/**
 * Decodes a value from base64 with a prefix.
 * @remarks Prefixes are: 'str:' for string and 'bin:' for ArrayBuffer.
 * @public
 * @param value - The value to decode from base64.
 * @returns The decoded value.
 */
export const decodeFromBase64WithPrefix = (value) => {
    const parts = value.split(':');
    let prefix;
    let base64Value;
    if (parts.length === 2) {
        [prefix, base64Value] = parts;
    }
    else {
        base64Value = value;
    }
    const decodedValue = decodeFromBase64(base64Value);
    if (prefix === 'str') {
        const textDecoder = new TextDecoder('utf-8');
        return textDecoder.decode(decodedValue);
    }
    else if (prefix === 'bin') {
        return decodedValue;
    }
    return decodedValue;
};
