/**
 * Encodes the given value to base64.
 * @public
 * @param value - The value to encode to base64.
 * @returns The base64 encoded value.
 */
export const encodeToBase64 = (value) => {
    if (typeof value === 'string') {
        return btoa(value);
    }
    else if (value instanceof ArrayBuffer) {
        const buffer = new Uint8Array(value);
        const binaryString = buffer.reduce((data, byte) => data + String.fromCharCode(byte), '');
        return btoa(binaryString);
    }
    return '';
};
/**
 * Encodes the given value with a prefix to base64.
 * @remarks Prefixes are: 'str:' for string and 'bin:' for ArrayBuffer.
 * @public
 * @param value - The value to encode to base64.
 * @returns The base64 encoded value with a prefix.
 */
export const encodeToBase64WithPrefix = (value) => {
    const base64Value = encodeToBase64(value);
    if (typeof value === 'string') {
        return `str:${base64Value}`;
    }
    else if (value instanceof ArrayBuffer) {
        return `bin:${base64Value}`;
    }
    return '';
};
